@@ -1,7 +1,7 @@
 print.hd <-
 function(x,...){
 	class(x)<-NULL
-	print(x,digits=3,na.print='.',...)
+	print(x,digits=3,na.print='.')
 	class(x)<-'hd'
 }
 
