@@ -9,7 +9,7 @@ clx<-Crabs[,1]
 prms<-hddc(X,k=1:6,model=c("AkjBkQkDk","ABkQkD"))
 prms
 res<-predict(prms,X,clx)
-prms<-hddc(X,k=1:7,model=c(4:5,10:11),cgraph=TRUE)
+prms<-hddc(X,k=2:6,model=c(4:5,10),cgraph=TRUE)
 
 #Now a PCA on the "Crabs" dataset is done on the two first 
 #principal axis.
